@@ -1,6 +1,9 @@
 from socket import gethostname
 
 from discord_webhook import DiscordEmbed, DiscordWebhook
+from yaml import dump
+
+from .utils import Code
 
 
 class DiscordLogger:
@@ -23,7 +26,6 @@ class DiscordLogger:
             raise ValueError("The field webhook_url cannot be:", webhook_url)
         self.webhook_url = str(webhook_url)
 
-
         self.application_name = kwargs.get("application_name", "Application")
         if self.application_name is not None:
             self.application_name = str(self.application_name)
@@ -36,7 +38,7 @@ class DiscordLogger:
         if self.service_icon_url is not None:
             self.service_icon_url = str(self.service_icon_url)
 
-        self.service_environment = kwargs.get("service_environment", "Production")
+        self.service_environment = kwargs.get("service_environment")
         if self.service_environment is not None:
             self.service_environment = str(self.service_environment)
 
@@ -46,50 +48,54 @@ class DiscordLogger:
         if self.default_level not in self.COLORS.keys():
             self.default_level = "default"
 
-        self.discord = DiscordWebhook(url=self.webhook_url, username=self.application_name)
+        self.discord = DiscordWebhook(
+            url=self.webhook_url, username=self.application_name
+        )
 
     def __remove_embeds(self):
         existing_embeds = self.discord.get_embeds()
         for i in reversed(range(0, len(existing_embeds))):
             self.discord.remove_embed(i)
 
-    def construct(self, title, description, level=None, error=None):
+    def construct(self, title, description, level=None, error=None, metadata=None):
         self.__remove_embeds()
 
+        _title = ""
         if title is not None:
-            title = str(title)
+            _title = str(title)
+
+        _description = ""
         if description is not None:
-            description = str(description)
+            _description = str(description) + "\n\n"
 
-        if level is None:
-            level = self.default_level
+        _level = level
+        if _level is None:
+            _level = self.default_level
+        _color = self.COLORS.get(_level)
 
-        color = self.COLORS.get(level)
+        embed = DiscordEmbed(title=_title, description=_description, color=_color)
+
+        embed.set_author(name=self.service_name, icon_url=self.service_icon_url)
+
+        if metadata is not None:
+            _metadata = dump(
+                metadata, indent=4, default_flow_style=False, sort_keys=False
+            )
+
+            embed.add_embed_field(
+                name="Metadata", value=Code(str(_metadata)), inline=False
+            )
 
         if error is not None:
-            color = self.COLORS.get("error")
-            if description is None:
-                description = "```" + str(error) + "```"
-            else:
-                description = description + "\n" + "```" + str(error) + "```"
+            embed.add_embed_field(name="Error", value=Code(str(error)), inline=False)
 
-        embed = DiscordEmbed(title=title, description=description, color=color)
-
-        embed.set_author(
-            name=self.service_name,
-            icon_url=self.service_icon_url,
-        )
+            _color = self.COLORS.get("error")
+            embed.set_color(_color)
 
         if self.service_environment is not None:
-            embed.add_embed_field(
-                name="Environment",
-                value=self.service_environment
-            )
+            embed.add_embed_field(name="Environment", value=self.service_environment)
         if self.host_name is not None:
-            embed.add_embed_field(
-                name="Host",
-                value=self.host_name
-            )
+            embed.add_embed_field(name="Host", value=self.host_name)
 
         embed.set_timestamp()
 
